update

package
v0.1.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckInBackground

func CheckInBackground(currentVersion string) func()

CheckInBackground checks for a newer release in a background goroutine. Returns a function that, when called after the TUI exits, prints a notice if a newer version was found. Silently does nothing on any error.

func Run

func Run(currentVersion string)

Types

This section is empty.

Jump to